# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/snapshot_schedule_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import snapshot_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2
from yandex.cloud.compute.v1 import snapshot_schedule_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/snapshot_schedule_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/compute/v1/snapshot_schedule_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a&yandex/cloud/compute/v1/snapshot.proto\x1a/yandex/cloud/compute/v1/snapshot_schedule.proto\x1a&yandex/cloud/operation/operation.proto\":\n\x1aGetSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"z\n\x1cListSnapshotSchedulesRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\"\x7f\n\x1dListSnapshotSchedulesResponse\x12\x45\n\x12snapshot_schedules\x18\x01 \x03(\x0b\x32).yandex.cloud.compute.v1.SnapshotSchedule\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xcf\x03\n\x1d\x43reateSnapshotScheduleRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12R\n\x06labels\x18\x04 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.LabelsEntry\x12@\n\x0fschedule_policy\x18\x05 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\x07 \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\x08 \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x12\x10\n\x08\x64isk_ids\x18\t \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10retention_policy\">\n\x1e\x43reateSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"\xf9\x03\n\x1dUpdateSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12R\n\x06labels\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.LabelsEntry\x12@\n\x0fschedule_policy\x18\x06 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\x08 \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\t \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10retention_policy\">\n\x1eUpdateSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"=\n\x1d\x44\x65leteSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\">\n\x1e\x44\x65leteSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\">\n\x1e\x44isableSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"?\n\x1f\x44isableSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"=\n\x1d\x45nableSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\">\n\x1e\x45nableSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"l\n%ListSnapshotScheduleOperationsRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"x\n&ListSnapshotScheduleOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"k\n$ListSnapshotScheduleSnapshotsRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n%ListSnapshotScheduleSnapshotsResponse\x12\x34\n\tsnapshots\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n ListSnapshotScheduleDisksRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"j\n!ListSnapshotScheduleDisksResponse\x12,\n\x05\x64isks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Disk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"_\n\"UpdateSnapshotScheduleDisksRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x0e\n\x06remove\x18\x02 \x03(\t\x12\x0b\n\x03\x61\x64\x64\x18\x03 \x03(\t\"C\n#UpdateSnapshotScheduleDisksMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t2\xa4\x12\n\x17SnapshotScheduleService\x12\xa3\x01\n\x03Get\x12\x33.yandex.cloud.compute.v1.GetSnapshotScheduleRequest\x1a).yandex.cloud.compute.v1.SnapshotSchedule\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/compute/v1/snapshotSchedules/{snapshot_schedule_id}\x12\x9c\x01\n\x04List\x12\x35.yandex.cloud.compute.v1.ListSnapshotSchedulesRequest\x1a\x36.yandex.cloud.compute.v1.ListSnapshotSchedulesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/compute/v1/snapshotSchedules\x12\xc3\x01\n\x06\x43reate\x12\x36.yandex.cloud.compute.v1.CreateSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02\"\"\x1d/compute/v1/snapshotSchedules:\x01*\xb2\xd2*2\n\x1e\x43reateSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x12\xda\x01\n\x06Update\x12\x36.yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"u\x82\xd3\xe4\x93\x02\x39\x32\x34/compute/v1/snapshotSchedules/{snapshot_schedule_id}:\x01*\xb2\xd2*2\n\x1eUpdateSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x12\xdc\x01\n\x06\x44\x65lete\x12\x36.yandex.cloud.compute.v1.DeleteSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"w\x82\xd3\xe4\x93\x02\x36*4/compute/v1/snapshotSchedules/{snapshot_schedule_id}\xb2\xd2*7\n\x1e\x44\x65leteSnapshotScheduleMetadata\x12\x15google.protobuf.Empty\x12\xf6\x01\n\x0bUpdateDisks\x12;.yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\x82\xd3\xe4\x93\x02\x45\x32@/compute/v1/snapshotSchedules/{snapshot_schedule_id}:updateDisks:\x01*\xb2\xd2*7\n#UpdateSnapshotScheduleDisksMetadata\x12\x10SnapshotSchedule\x12\xe5\x01\n\x07\x44isable\x12\x37.yandex.cloud.compute.v1.DisableSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"~\x82\xd3\xe4\x93\x02\x41\"</compute/v1/snapshotSchedules/{snapshot_schedule_id}:disable:\x01*\xb2\xd2*3\n\x1f\x44isableSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x12\xe1\x01\n\x06\x45nable\x12\x36.yandex.cloud.compute.v1.EnableSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"|\x82\xd3\xe4\x93\x02@\";/compute/v1/snapshotSchedules/{snapshot_schedule_id}:enable:\x01*\xb2\xd2*2\n\x1e\x45nableSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x12\xda\x01\n\x0eListOperations\x12>.yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest\x1a?.yandex.cloud.compute.v1.ListSnapshotScheduleOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/compute/v1/snapshotSchedules/{snapshot_schedule_id}/operations\x12\xd6\x01\n\rListSnapshots\x12=.yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest\x1a>.yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/compute/v1/snapshotSchedules/{snapshot_schedule_id}/snapshots\x12\xc6\x01\n\tListDisks\x12\x39.yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest\x1a:.yandex.cloud.compute.v1.ListSnapshotScheduleDisksResponse\"B\x82\xd3\xe4\x93\x02<\x12:/compute/v1/snapshotSchedules/{snapshot_schedule_id}/disksBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])




_GETSNAPSHOTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='GetSnapshotScheduleRequest',
  full_name='yandex.cloud.compute.v1.GetSnapshotScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.GetSnapshotScheduleRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=437,
)


_LISTSNAPSHOTSCHEDULESREQUEST = _descriptor.Descriptor(
  name='ListSnapshotSchedulesRequest',
  full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=561,
)


_LISTSNAPSHOTSCHEDULESRESPONSE = _descriptor.Descriptor(
  name='ListSnapshotSchedulesResponse',
  full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedules', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesResponse.snapshot_schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListSnapshotSchedulesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=690,
)


_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1136,
)

_CREATESNAPSHOTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='CreateSnapshotScheduleRequest',
  full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_policy', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.schedule_policy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.retention_period', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_count', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.snapshot_count', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_spec', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.snapshot_spec', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_ids', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.disk_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='retention_policy', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.retention_policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=693,
  serialized_end=1156,
)


_CREATESNAPSHOTSCHEDULEMETADATA = _descriptor.Descriptor(
  name='CreateSnapshotScheduleMetadata',
  full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.CreateSnapshotScheduleMetadata.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1220,
)


_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1136,
)

_UPDATESNAPSHOTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='UpdateSnapshotScheduleRequest',
  full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_policy', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.schedule_policy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.retention_period', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_count', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.snapshot_count', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_spec', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.snapshot_spec', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='retention_policy', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.retention_policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1223,
  serialized_end=1728,
)


_UPDATESNAPSHOTSCHEDULEMETADATA = _descriptor.Descriptor(
  name='UpdateSnapshotScheduleMetadata',
  full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleMetadata.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1792,
)


_DELETESNAPSHOTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='DeleteSnapshotScheduleRequest',
  full_name='yandex.cloud.compute.v1.DeleteSnapshotScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.DeleteSnapshotScheduleRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1855,
)


_DELETESNAPSHOTSCHEDULEMETADATA = _descriptor.Descriptor(
  name='DeleteSnapshotScheduleMetadata',
  full_name='yandex.cloud.compute.v1.DeleteSnapshotScheduleMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.DeleteSnapshotScheduleMetadata.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1919,
)


_DISABLESNAPSHOTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='DisableSnapshotScheduleRequest',
  full_name='yandex.cloud.compute.v1.DisableSnapshotScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.DisableSnapshotScheduleRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=1983,
)


_DISABLESNAPSHOTSCHEDULEMETADATA = _descriptor.Descriptor(
  name='DisableSnapshotScheduleMetadata',
  full_name='yandex.cloud.compute.v1.DisableSnapshotScheduleMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.DisableSnapshotScheduleMetadata.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1985,
  serialized_end=2048,
)


_ENABLESNAPSHOTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='EnableSnapshotScheduleRequest',
  full_name='yandex.cloud.compute.v1.EnableSnapshotScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.EnableSnapshotScheduleRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2050,
  serialized_end=2111,
)


_ENABLESNAPSHOTSCHEDULEMETADATA = _descriptor.Descriptor(
  name='EnableSnapshotScheduleMetadata',
  full_name='yandex.cloud.compute.v1.EnableSnapshotScheduleMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.EnableSnapshotScheduleMetadata.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2113,
  serialized_end=2175,
)


_LISTSNAPSHOTSCHEDULEOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListSnapshotScheduleOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2177,
  serialized_end=2285,
)


_LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListSnapshotScheduleOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2287,
  serialized_end=2407,
)


_LISTSNAPSHOTSCHEDULESNAPSHOTSREQUEST = _descriptor.Descriptor(
  name='ListSnapshotScheduleSnapshotsRequest',
  full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2409,
  serialized_end=2516,
)


_LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE = _descriptor.Descriptor(
  name='ListSnapshotScheduleSnapshotsResponse',
  full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshots', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsResponse.snapshots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2636,
)


_LISTSNAPSHOTSCHEDULEDISKSREQUEST = _descriptor.Descriptor(
  name='ListSnapshotScheduleDisksRequest',
  full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2638,
  serialized_end=2741,
)


_LISTSNAPSHOTSCHEDULEDISKSRESPONSE = _descriptor.Descriptor(
  name='ListSnapshotScheduleDisksResponse',
  full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disks', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksResponse.disks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListSnapshotScheduleDisksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2743,
  serialized_end=2849,
)


_UPDATESNAPSHOTSCHEDULEDISKSREQUEST = _descriptor.Descriptor(
  name='UpdateSnapshotScheduleDisksRequest',
  full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest.remove', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest.add', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2851,
  serialized_end=2946,
)


_UPDATESNAPSHOTSCHEDULEDISKSMETADATA = _descriptor.Descriptor(
  name='UpdateSnapshotScheduleDisksMetadata',
  full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshot_schedule_id', full_name='yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksMetadata.snapshot_schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2948,
  serialized_end=3015,
)

_LISTSNAPSHOTSCHEDULESRESPONSE.fields_by_name['snapshot_schedules'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2._SNAPSHOTSCHEDULE
_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY.containing_type = _CREATESNAPSHOTSCHEDULEREQUEST
_CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['labels'].message_type = _CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY
_CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['schedule_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2._SCHEDULEPOLICY
_CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['snapshot_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2._SNAPSHOTSPEC
_CREATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy'].fields.append(
  _CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['retention_period'])
_CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['retention_period'].containing_oneof = _CREATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy']
_CREATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy'].fields.append(
  _CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['snapshot_count'])
_CREATESNAPSHOTSCHEDULEREQUEST.fields_by_name['snapshot_count'].containing_oneof = _CREATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy']
_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY.containing_type = _UPDATESNAPSHOTSCHEDULEREQUEST
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['labels'].message_type = _UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['schedule_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2._SCHEDULEPOLICY
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['snapshot_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2._SNAPSHOTSPEC
_UPDATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy'].fields.append(
  _UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['retention_period'])
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['retention_period'].containing_oneof = _UPDATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy']
_UPDATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy'].fields.append(
  _UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['snapshot_count'])
_UPDATESNAPSHOTSCHEDULEREQUEST.fields_by_name['snapshot_count'].containing_oneof = _UPDATESNAPSHOTSCHEDULEREQUEST.oneofs_by_name['retention_policy']
_LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE.fields_by_name['snapshots'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2._SNAPSHOT
_LISTSNAPSHOTSCHEDULEDISKSRESPONSE.fields_by_name['disks'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISK
DESCRIPTOR.message_types_by_name['GetSnapshotScheduleRequest'] = _GETSNAPSHOTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotSchedulesRequest'] = _LISTSNAPSHOTSCHEDULESREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotSchedulesResponse'] = _LISTSNAPSHOTSCHEDULESRESPONSE
DESCRIPTOR.message_types_by_name['CreateSnapshotScheduleRequest'] = _CREATESNAPSHOTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['CreateSnapshotScheduleMetadata'] = _CREATESNAPSHOTSCHEDULEMETADATA
DESCRIPTOR.message_types_by_name['UpdateSnapshotScheduleRequest'] = _UPDATESNAPSHOTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['UpdateSnapshotScheduleMetadata'] = _UPDATESNAPSHOTSCHEDULEMETADATA
DESCRIPTOR.message_types_by_name['DeleteSnapshotScheduleRequest'] = _DELETESNAPSHOTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['DeleteSnapshotScheduleMetadata'] = _DELETESNAPSHOTSCHEDULEMETADATA
DESCRIPTOR.message_types_by_name['DisableSnapshotScheduleRequest'] = _DISABLESNAPSHOTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['DisableSnapshotScheduleMetadata'] = _DISABLESNAPSHOTSCHEDULEMETADATA
DESCRIPTOR.message_types_by_name['EnableSnapshotScheduleRequest'] = _ENABLESNAPSHOTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['EnableSnapshotScheduleMetadata'] = _ENABLESNAPSHOTSCHEDULEMETADATA
DESCRIPTOR.message_types_by_name['ListSnapshotScheduleOperationsRequest'] = _LISTSNAPSHOTSCHEDULEOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotScheduleOperationsResponse'] = _LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListSnapshotScheduleSnapshotsRequest'] = _LISTSNAPSHOTSCHEDULESNAPSHOTSREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotScheduleSnapshotsResponse'] = _LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE
DESCRIPTOR.message_types_by_name['ListSnapshotScheduleDisksRequest'] = _LISTSNAPSHOTSCHEDULEDISKSREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotScheduleDisksResponse'] = _LISTSNAPSHOTSCHEDULEDISKSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSnapshotScheduleDisksRequest'] = _UPDATESNAPSHOTSCHEDULEDISKSREQUEST
DESCRIPTOR.message_types_by_name['UpdateSnapshotScheduleDisksMetadata'] = _UPDATESNAPSHOTSCHEDULEDISKSMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSnapshotScheduleRequest = _reflection.GeneratedProtocolMessageType('GetSnapshotScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSNAPSHOTSCHEDULEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetSnapshotScheduleRequest)
  })
_sym_db.RegisterMessage(GetSnapshotScheduleRequest)

ListSnapshotSchedulesRequest = _reflection.GeneratedProtocolMessageType('ListSnapshotSchedulesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotSchedulesRequest)
  })
_sym_db.RegisterMessage(ListSnapshotSchedulesRequest)

ListSnapshotSchedulesResponse = _reflection.GeneratedProtocolMessageType('ListSnapshotSchedulesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotSchedulesResponse)
  })
_sym_db.RegisterMessage(ListSnapshotSchedulesResponse)

CreateSnapshotScheduleRequest = _reflection.GeneratedProtocolMessageType('CreateSnapshotScheduleRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESNAPSHOTSCHEDULEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateSnapshotScheduleRequest)
  })
_sym_db.RegisterMessage(CreateSnapshotScheduleRequest)
_sym_db.RegisterMessage(CreateSnapshotScheduleRequest.LabelsEntry)

CreateSnapshotScheduleMetadata = _reflection.GeneratedProtocolMessageType('CreateSnapshotScheduleMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESNAPSHOTSCHEDULEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateSnapshotScheduleMetadata)
  })
_sym_db.RegisterMessage(CreateSnapshotScheduleMetadata)

UpdateSnapshotScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateSnapshotScheduleRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESNAPSHOTSCHEDULEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateSnapshotScheduleRequest)
_sym_db.RegisterMessage(UpdateSnapshotScheduleRequest.LabelsEntry)

UpdateSnapshotScheduleMetadata = _reflection.GeneratedProtocolMessageType('UpdateSnapshotScheduleMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESNAPSHOTSCHEDULEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateSnapshotScheduleMetadata)
  })
_sym_db.RegisterMessage(UpdateSnapshotScheduleMetadata)

DeleteSnapshotScheduleRequest = _reflection.GeneratedProtocolMessageType('DeleteSnapshotScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESNAPSHOTSCHEDULEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteSnapshotScheduleRequest)
  })
_sym_db.RegisterMessage(DeleteSnapshotScheduleRequest)

DeleteSnapshotScheduleMetadata = _reflection.GeneratedProtocolMessageType('DeleteSnapshotScheduleMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESNAPSHOTSCHEDULEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteSnapshotScheduleMetadata)
  })
_sym_db.RegisterMessage(DeleteSnapshotScheduleMetadata)

DisableSnapshotScheduleRequest = _reflection.GeneratedProtocolMessageType('DisableSnapshotScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLESNAPSHOTSCHEDULEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DisableSnapshotScheduleRequest)
  })
_sym_db.RegisterMessage(DisableSnapshotScheduleRequest)

DisableSnapshotScheduleMetadata = _reflection.GeneratedProtocolMessageType('DisableSnapshotScheduleMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DISABLESNAPSHOTSCHEDULEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DisableSnapshotScheduleMetadata)
  })
_sym_db.RegisterMessage(DisableSnapshotScheduleMetadata)

EnableSnapshotScheduleRequest = _reflection.GeneratedProtocolMessageType('EnableSnapshotScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLESNAPSHOTSCHEDULEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.EnableSnapshotScheduleRequest)
  })
_sym_db.RegisterMessage(EnableSnapshotScheduleRequest)

EnableSnapshotScheduleMetadata = _reflection.GeneratedProtocolMessageType('EnableSnapshotScheduleMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ENABLESNAPSHOTSCHEDULEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.EnableSnapshotScheduleMetadata)
  })
_sym_db.RegisterMessage(EnableSnapshotScheduleMetadata)

ListSnapshotScheduleOperationsRequest = _reflection.GeneratedProtocolMessageType('ListSnapshotScheduleOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULEOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest)
  })
_sym_db.RegisterMessage(ListSnapshotScheduleOperationsRequest)

ListSnapshotScheduleOperationsResponse = _reflection.GeneratedProtocolMessageType('ListSnapshotScheduleOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotScheduleOperationsResponse)
  })
_sym_db.RegisterMessage(ListSnapshotScheduleOperationsResponse)

ListSnapshotScheduleSnapshotsRequest = _reflection.GeneratedProtocolMessageType('ListSnapshotScheduleSnapshotsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULESNAPSHOTSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest)
  })
_sym_db.RegisterMessage(ListSnapshotScheduleSnapshotsRequest)

ListSnapshotScheduleSnapshotsResponse = _reflection.GeneratedProtocolMessageType('ListSnapshotScheduleSnapshotsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsResponse)
  })
_sym_db.RegisterMessage(ListSnapshotScheduleSnapshotsResponse)

ListSnapshotScheduleDisksRequest = _reflection.GeneratedProtocolMessageType('ListSnapshotScheduleDisksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULEDISKSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest)
  })
_sym_db.RegisterMessage(ListSnapshotScheduleDisksRequest)

ListSnapshotScheduleDisksResponse = _reflection.GeneratedProtocolMessageType('ListSnapshotScheduleDisksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSCHEDULEDISKSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListSnapshotScheduleDisksResponse)
  })
_sym_db.RegisterMessage(ListSnapshotScheduleDisksResponse)

UpdateSnapshotScheduleDisksRequest = _reflection.GeneratedProtocolMessageType('UpdateSnapshotScheduleDisksRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESNAPSHOTSCHEDULEDISKSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest)
  })
_sym_db.RegisterMessage(UpdateSnapshotScheduleDisksRequest)

UpdateSnapshotScheduleDisksMetadata = _reflection.GeneratedProtocolMessageType('UpdateSnapshotScheduleDisksMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESNAPSHOTSCHEDULEDISKSMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksMetadata)
  })
_sym_db.RegisterMessage(UpdateSnapshotScheduleDisksMetadata)


DESCRIPTOR._options = None
_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY._options = None
_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY._options = None

_SNAPSHOTSCHEDULESERVICE = _descriptor.ServiceDescriptor(
  name='SnapshotScheduleService',
  full_name='yandex.cloud.compute.v1.SnapshotScheduleService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3018,
  serialized_end=5358,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSNAPSHOTSCHEDULEREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2._SNAPSHOTSCHEDULE,
    serialized_options=b'\202\323\344\223\0026\0224/compute/v1/snapshotSchedules/{snapshot_schedule_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSNAPSHOTSCHEDULESREQUEST,
    output_type=_LISTSNAPSHOTSCHEDULESRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/compute/v1/snapshotSchedules',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESNAPSHOTSCHEDULEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\"\"\035/compute/v1/snapshotSchedules:\001*\262\322*2\n\036CreateSnapshotScheduleMetadata\022\020SnapshotSchedule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESNAPSHOTSCHEDULEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/compute/v1/snapshotSchedules/{snapshot_schedule_id}:\001*\262\322*2\n\036UpdateSnapshotScheduleMetadata\022\020SnapshotSchedule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESNAPSHOTSCHEDULEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026*4/compute/v1/snapshotSchedules/{snapshot_schedule_id}\262\322*7\n\036DeleteSnapshotScheduleMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDisks',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.UpdateDisks',
    index=5,
    containing_service=None,
    input_type=_UPDATESNAPSHOTSCHEDULEDISKSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002E2@/compute/v1/snapshotSchedules/{snapshot_schedule_id}:updateDisks:\001*\262\322*7\n#UpdateSnapshotScheduleDisksMetadata\022\020SnapshotSchedule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Disable',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.Disable',
    index=6,
    containing_service=None,
    input_type=_DISABLESNAPSHOTSCHEDULEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002A\"</compute/v1/snapshotSchedules/{snapshot_schedule_id}:disable:\001*\262\322*3\n\037DisableSnapshotScheduleMetadata\022\020SnapshotSchedule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Enable',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.Enable',
    index=7,
    containing_service=None,
    input_type=_ENABLESNAPSHOTSCHEDULEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@\";/compute/v1/snapshotSchedules/{snapshot_schedule_id}:enable:\001*\262\322*2\n\036EnableSnapshotScheduleMetadata\022\020SnapshotSchedule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.ListOperations',
    index=8,
    containing_service=None,
    input_type=_LISTSNAPSHOTSCHEDULEOPERATIONSREQUEST,
    output_type=_LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/compute/v1/snapshotSchedules/{snapshot_schedule_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSnapshots',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.ListSnapshots',
    index=9,
    containing_service=None,
    input_type=_LISTSNAPSHOTSCHEDULESNAPSHOTSREQUEST,
    output_type=_LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/compute/v1/snapshotSchedules/{snapshot_schedule_id}/snapshots',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDisks',
    full_name='yandex.cloud.compute.v1.SnapshotScheduleService.ListDisks',
    index=10,
    containing_service=None,
    input_type=_LISTSNAPSHOTSCHEDULEDISKSREQUEST,
    output_type=_LISTSNAPSHOTSCHEDULEDISKSRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/compute/v1/snapshotSchedules/{snapshot_schedule_id}/disks',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SNAPSHOTSCHEDULESERVICE)

DESCRIPTOR.services_by_name['SnapshotScheduleService'] = _SNAPSHOTSCHEDULESERVICE

# @@protoc_insertion_point(module_scope)
